searchData={"items":[{"type":"behaviour","title":"Authoritex","doc":"Elixir authority lookup behavior","ref":"Authoritex.html"},{"type":"function","title":"Authoritex.authorities/0","doc":"Lists the available authories, returning a list of\n{implementation_module, authority_code, authority_description}\n\nExample:\n  ```\n  iex> Authoritex.authorities()\n  [\n    {Authoritex.FAST.CorporateName, \"fast-corporate-name\", \"Faceted Application of Subject Terminology -- Corporate Name\"},\n    {Authoritex.FAST.EventName, \"fast-event-name\", \"Faceted Application of Subject Terminology -- Event Name\"},\n    {Authoritex.FAST.Form, \"fast-form\", \"Faceted Application of Subject Terminology -- Form/Genre\"},\n    {Authoritex.FAST.Geographic, \"fast-geographic\", \"Faceted Application of Subject Terminology -- Geographic\"},\n    {Authoritex.FAST.Personal, \"fast-personal\", \"Faceted Application of Subject Terminology -- Personal\"},\n    {Authoritex.FAST.Topical, \"fast-topical\", \"Faceted Application of Subject Terminology -- Topical\"},\n    {Authoritex.FAST.UniformTitle, \"fast-uniform-title\", \"Faceted Application of Subject Terminology -- Uniform Title\"},\n    {Authoritex.FAST, \"fast\", \"Faceted Application of Subject Terminology\"},\n    {Authoritex.GeoNames, \"geonames\", \"GeoNames geographical database\"},\n    {Authoritex.Getty.AAT, \"aat\", \"Getty Art & Architecture Thesaurus (AAT)\"},\n    {Authoritex.Getty.TGN, \"tgn\", \"Getty Thesaurus of Geographic Names (TGN)\"},\n    {Authoritex.Getty.ULAN, \"ulan\", \"Getty Union List of Artist Names (ULAN)\"},\n    {Authoritex.Getty, \"getty\", \"Getty Vocabularies\"},\n    {Authoritex.LOC.Languages, \"lclang\", \"Library of Congress MARC List for Languages\"},\n    {Authoritex.LOC.Names, \"lcnaf\", \"Library of Congress Name Authority File\"},\n    {Authoritex.LOC.SubjectHeadings, \"lcsh\", \"Library of Congress Subject Headings\"},\n    {Authoritex.LOC, \"loc\", \"Library of Congress Linked Data\"}\n  ]\n  ```","ref":"Authoritex.html#authorities/0"},{"type":"type","title":"Authoritex.authority/0","doc":"","ref":"Authoritex.html#t:authority/0"},{"type":"function","title":"Authoritex.authority_for/1","doc":"","ref":"Authoritex.html#authority_for/1"},{"type":"callback","title":"Authoritex.can_resolve?/1","doc":"Returns true if the module can resolve the given identifier","ref":"Authoritex.html#c:can_resolve?/1"},{"type":"callback","title":"Authoritex.code/0","doc":"Returns the unique short code for the authority","ref":"Authoritex.html#c:code/0"},{"type":"callback","title":"Authoritex.description/0","doc":"Returns a human-readable description of the authority","ref":"Authoritex.html#c:description/0"},{"type":"function","title":"Authoritex.fetch/1","doc":"Returns a label given an id.\n\nExamples:\n  ```\n  iex> Authoritex.fetch(\"http://id.loc.gov/authorities/names/no2011087251\")\n  {:ok, \"Valim, Jose\"}\n\n  iex> Authoritex.fetch(\"http://id.loc.gov/authorities/names/unknown-id\")\n  {:error, 404}\n\n  iex> Authoritex.fetch(\"http://fake.authority.org/not-a-real-thing\")\n  {:error, :unknown_authority}\n  ```","ref":"Authoritex.html#fetch/1"},{"type":"callback","title":"Authoritex.fetch/1","doc":"Fetches a label (and optional hint string) for a specified resource","ref":"Authoritex.html#c:fetch/1"},{"type":"type","title":"Authoritex.fetch_result/0","doc":"","ref":"Authoritex.html#t:fetch_result/0"},{"type":"function","title":"Authoritex.search/2","doc":"Returns search results for a given query.\n\nExamples:\n  ```\n  iex> Authoritex.search(\"lcnaf\", \"valim\")\n  {:ok,\n  [\n    %{id: \"info:lc/authorities/names/n2013200729\", label: \"Valim, Alexandre Busko\"},\n    %{id: \"info:lc/authorities/names/nb2006000541\", label: \"Levitin, Valim\"},\n    %{id: \"info:lc/authorities/names/n88230271\", label: \"Valim, Anthony Terra, 1919-\"},\n    %{id: \"info:lc/authorities/names/no2019037344\", label: \"Melo, Glenda Cristina Valim de\"},\n    %{id: \"info:lc/authorities/names/no2012078919\", label: \"Mansan, Jaime Valim\"},\n    %{id: \"info:lc/authorities/names/no2001072420\", label: \"Lucisano-Valim, Yara Maria\"},\n    %{id: \"info:lc/authorities/names/no2011087251\", label: \"Valim, Jose\"},\n    %{id: \"info:lc/authorities/names/no2019110111\", label: \"Valim, Patrícia\"},\n    %{id: \"info:lc/authorities/names/n2014206721\", label: \"Valim, Rafael\"},\n    %{id: \"info:lc/authorities/names/no2009021335\", label: \"Melo, Cimara\"}\n  ]}\n\n  iex> Authoritex.search(\"lcnaf\", \"blergh\")\n  {:ok, []}\n\n  iex> Authoritex.search(\"blergh\", \"valim\")\n  {:error, \"Unknown authority: blergh\"}\n  ```","ref":"Authoritex.html#search/2"},{"type":"callback","title":"Authoritex.search/2","doc":"Returns a list of search results (and optional hints) matching a query","ref":"Authoritex.html#c:search/2"},{"type":"function","title":"Authoritex.search/3","doc":"Like `Authoritex.search/2` but with a specific maximum number of results","ref":"Authoritex.html#search/3"},{"type":"type","title":"Authoritex.search_result/0","doc":"","ref":"Authoritex.html#t:search_result/0"},{"type":"module","title":"Authoritex.FAST","doc":"Authoritex implementation for Faceted Application of Subject Terminology","ref":"Authoritex.FAST.html"},{"type":"module","title":"Authoritex.FAST.Base","doc":"Abstract Authoritex implementation for FAST authorities & vocabularies","ref":"Authoritex.FAST.Base.html"},{"type":"module","title":"Authoritex.FAST.CorporateName","doc":"Authoritex implementation for Faceted Application of Subject Terminology -- Corporate Name","ref":"Authoritex.FAST.CorporateName.html"},{"type":"module","title":"Authoritex.FAST.EventName","doc":"Authoritex implementation for Faceted Application of Subject Terminology -- Event Name","ref":"Authoritex.FAST.EventName.html"},{"type":"module","title":"Authoritex.FAST.Form","doc":"Authoritex implementation for Faceted Application of Subject Terminology -- Form/Genre","ref":"Authoritex.FAST.Form.html"},{"type":"module","title":"Authoritex.FAST.Geographic","doc":"Authoritex implementation for Faceted Application of Subject Terminology -- Geographic","ref":"Authoritex.FAST.Geographic.html"},{"type":"module","title":"Authoritex.FAST.Personal","doc":"Authoritex implementation for Faceted Application of Subject Terminology -- Personal","ref":"Authoritex.FAST.Personal.html"},{"type":"module","title":"Authoritex.FAST.Topical","doc":"Authoritex implementation for Faceted Application of Subject Terminology -- Topical","ref":"Authoritex.FAST.Topical.html"},{"type":"module","title":"Authoritex.FAST.UniformTitle","doc":"Authoritex implementation for Faceted Application of Subject Terminology -- Uniform Title","ref":"Authoritex.FAST.UniformTitle.html"},{"type":"module","title":"Authoritex.GeoNames","doc":"Authoritex implementation for GeoNames webservice","ref":"Authoritex.GeoNames.html"},{"type":"module","title":"Authoritex.Getty","doc":"Authoritex implementation for the Getty Vocabularies","ref":"Authoritex.Getty.html"},{"type":"function","title":"Authoritex.Getty.process_result/1","doc":"","ref":"Authoritex.Getty.html#process_result/1"},{"type":"function","title":"Authoritex.Getty.sparql_fetch/1","doc":"","ref":"Authoritex.Getty.html#sparql_fetch/1"},{"type":"module","title":"Authoritex.Getty.AAT","doc":"Authoritex implementation for the Getty Art & Architecture Thesaurus (AAT)","ref":"Authoritex.Getty.AAT.html"},{"type":"function","title":"Authoritex.Getty.AAT.process_result/1","doc":"","ref":"Authoritex.Getty.AAT.html#process_result/1"},{"type":"function","title":"Authoritex.Getty.AAT.sparql_fetch/1","doc":"","ref":"Authoritex.Getty.AAT.html#sparql_fetch/1"},{"type":"module","title":"Authoritex.Getty.Base","doc":"Abstract Authoritex implementation for Getty authorities & vocabularies","ref":"Authoritex.Getty.Base.html"},{"type":"module","title":"Authoritex.Getty.TGN","doc":"Authoritex implementation for the Getty Thesaurus of Geographic Names (TGN)","ref":"Authoritex.Getty.TGN.html"},{"type":"function","title":"Authoritex.Getty.TGN.process_result/1","doc":"","ref":"Authoritex.Getty.TGN.html#process_result/1"},{"type":"function","title":"Authoritex.Getty.TGN.sparql_fetch/1","doc":"","ref":"Authoritex.Getty.TGN.html#sparql_fetch/1"},{"type":"module","title":"Authoritex.Getty.ULAN","doc":"Authoritex implementation for the Getty Union List of Artist Names (ULAN)","ref":"Authoritex.Getty.ULAN.html"},{"type":"function","title":"Authoritex.Getty.ULAN.process_result/1","doc":"","ref":"Authoritex.Getty.ULAN.html#process_result/1"},{"type":"function","title":"Authoritex.Getty.ULAN.sparql_fetch/1","doc":"","ref":"Authoritex.Getty.ULAN.html#sparql_fetch/1"},{"type":"module","title":"Authoritex.HTTP.Client","doc":"HTTP client for Authoritex","ref":"Authoritex.HTTP.Client.html"},{"type":"type","title":"Authoritex.HTTP.Client.body/0","doc":"","ref":"Authoritex.HTTP.Client.html#t:body/0"},{"type":"function","title":"Authoritex.HTTP.Client.delete/3","doc":"Issues a DELETE request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#delete/3"},{"type":"function","title":"Authoritex.HTTP.Client.delete!/3","doc":"Issues a DELETE request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#delete!/3"},{"type":"function","title":"Authoritex.HTTP.Client.get/3","doc":"Issues a GET request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#get/3"},{"type":"function","title":"Authoritex.HTTP.Client.get!/3","doc":"Issues a GET request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#get!/3"},{"type":"function","title":"Authoritex.HTTP.Client.head/3","doc":"Issues a HEAD request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#head/3"},{"type":"function","title":"Authoritex.HTTP.Client.head!/3","doc":"Issues a HEAD request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#head!/3"},{"type":"type","title":"Authoritex.HTTP.Client.headers/0","doc":"","ref":"Authoritex.HTTP.Client.html#t:headers/0"},{"type":"type","title":"Authoritex.HTTP.Client.method/0","doc":"","ref":"Authoritex.HTTP.Client.html#t:method/0"},{"type":"type","title":"Authoritex.HTTP.Client.options/0","doc":"","ref":"Authoritex.HTTP.Client.html#t:options/0"},{"type":"function","title":"Authoritex.HTTP.Client.options/3","doc":"Issues an OPTIONS request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#options/3"},{"type":"function","title":"Authoritex.HTTP.Client.options!/3","doc":"Issues a OPTIONS request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#options!/3"},{"type":"type","title":"Authoritex.HTTP.Client.params/0","doc":"","ref":"Authoritex.HTTP.Client.html#t:params/0"},{"type":"function","title":"Authoritex.HTTP.Client.patch/4","doc":"Issues a PATCH request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#patch/4"},{"type":"function","title":"Authoritex.HTTP.Client.patch!/4","doc":"Issues a PATCH request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#patch!/4"},{"type":"function","title":"Authoritex.HTTP.Client.post/4","doc":"Issues a POST request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#post/4"},{"type":"function","title":"Authoritex.HTTP.Client.post!/4","doc":"Issues a POST request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#post!/4"},{"type":"function","title":"Authoritex.HTTP.Client.process_headers/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_headers/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_request_body/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_request_body/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_request_headers/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_request_headers/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_request_options/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_request_options/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_request_params/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_request_params/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_request_url/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_request_url/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_response/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_response/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_response_body/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_response_body/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_response_chunk/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_response_chunk/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_response_headers/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_response_headers/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_response_status_code/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_response_status_code/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_status_code/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_status_code/1"},{"type":"function","title":"Authoritex.HTTP.Client.process_url/1","doc":"","ref":"Authoritex.HTTP.Client.html#process_url/1"},{"type":"function","title":"Authoritex.HTTP.Client.put/4","doc":"Issues a PUT request to the given url.\n\nReturns `{:ok, response}` if the request is successful, `{:error, reason}`\notherwise.\n\nSee `request/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#put/4"},{"type":"function","title":"Authoritex.HTTP.Client.put!/4","doc":"Issues a PUT request to the given url, raising an exception in case of\nfailure.\n\nIf the request does not fail, the response is returned.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#put!/4"},{"type":"type","title":"Authoritex.HTTP.Client.request/0","doc":"","ref":"Authoritex.HTTP.Client.html#t:request/0"},{"type":"function","title":"Authoritex.HTTP.Client.request/1","doc":"Issues an HTTP request using a `Request` struct.\n\nThis function returns `{:ok, response}`, `{:ok, async_response}`, or `{:ok, maybe_redirect}`\nif the request is successful, `{:error, reason}` otherwise.","ref":"Authoritex.HTTP.Client.html#request/1"},{"type":"function","title":"Redirect handling - Authoritex.HTTP.Client.request/1","doc":"If the option `:follow_redirect` is given, HTTP redirects are automatically follow if\nthe method is set to `:get` or `:head` and the response's `status_code` is `301`, `302` or\n`307`.\n\nIf the method is set to `:post`, then the only `status_code` that get's automatically\nfollowed is `303`.\n\nIf any other method or `status_code` is returned, then this function returns a\nreturns a `{:ok, %HTTPoison.MaybeRedirect{}}` containing the `redirect_url` for you to\nre-request with the method set to `:get`.","ref":"Authoritex.HTTP.Client.html#request/1-redirect-handling"},{"type":"function","title":"Examples - Authoritex.HTTP.Client.request/1","doc":"request = %HTTPoison.Request{\n      method: :post,\n      url: \"https://my.website.com\",\n      body: \"{\\\"foo\\\": 3}\",\n      headers: [{\"Accept\", \"application/json\"}]\n    }\n\n    request(request)","ref":"Authoritex.HTTP.Client.html#request/1-examples"},{"type":"function","title":"Authoritex.HTTP.Client.request/5","doc":"Issues an HTTP request with the given method to the given url.\n\nThis function is usually used indirectly by `get/3`, `post/4`, `put/4`, etc\n\nArgs:\n  * `method` - HTTP method as an atom (`:get`, `:head`, `:post`, `:put`,\n    `:delete`, etc.)\n  * `url` - target url as a binary string or char list\n  * `body` - request body. See more below\n  * `headers` - HTTP headers as an orddict (e.g., `[{\"Accept\", \"application/json\"}]`)\n  * `options` - Keyword list of options\n\nBody: see type `HTTPoison.Request`\n\nOptions: see type `HTTPoison.Request`\n\nThis function returns `{:ok, response}`, `{:ok, async_response}`, or `{:ok, maybe_redirect}`\nif the request is successful, `{:error, reason}` otherwise.","ref":"Authoritex.HTTP.Client.html#request/5"},{"type":"function","title":"Redirect handling - Authoritex.HTTP.Client.request/5","doc":"If the option `:follow_redirect` is given, HTTP redirects are automatically follow if\nthe method is set to `:get` or `:head` and the response's `status_code` is `301`, `302` or\n`307`.\n\nIf the method is set to `:post`, then the only `status_code` that get's automatically\nfollowed is `303`.\n\nIf any other method or `status_code` is returned, then this function returns a\nreturns a `{:ok, %HTTPoison.MaybeRedirect{}}` containing the `redirect_url` for you to\nre-request with the method set to `:get`.","ref":"Authoritex.HTTP.Client.html#request/5-redirect-handling"},{"type":"function","title":"Examples - Authoritex.HTTP.Client.request/5","doc":"request(:post, \"https://my.website.com\", \"{\\\"foo\\\": 3}\", [{\"Accept\", \"application/json\"}])","ref":"Authoritex.HTTP.Client.html#request/5-examples"},{"type":"function","title":"Authoritex.HTTP.Client.request!/5","doc":"Issues an HTTP request with the given method to the given url, raising an\nexception in case of failure.\n\n`request!/5` works exactly like `request/5` but it returns just the\nresponse in case of a successful request, raising an exception in case the\nrequest fails.","ref":"Authoritex.HTTP.Client.html#request!/5"},{"type":"function","title":"Authoritex.HTTP.Client.start/0","doc":"Starts HTTPoison and its dependencies.","ref":"Authoritex.HTTP.Client.html#start/0"},{"type":"function","title":"Authoritex.HTTP.Client.stream_next/1","doc":"Requests the next message to be streamed for a given `HTTPoison.AsyncResponse`.\n\nSee `request!/5` for more detailed information.","ref":"Authoritex.HTTP.Client.html#stream_next/1"},{"type":"type","title":"Authoritex.HTTP.Client.url/0","doc":"","ref":"Authoritex.HTTP.Client.html#t:url/0"},{"type":"module","title":"Authoritex.Homosaurus","doc":"Authoritex implementation for Homosaurus linked data vocabulary","ref":"Authoritex.Homosaurus.html"},{"type":"module","title":"Authoritex.LOC","doc":"Authoritex implementation for Library of Congress Linked Data","ref":"Authoritex.LOC.html"},{"type":"module","title":"Authoritex.LOC.Base","doc":"Abstract Authoritex implementation for Library of Congress authorities & vocabularies","ref":"Authoritex.LOC.Base.html"},{"type":"module","title":"Authoritex.LOC.GenreForms","doc":"Authoritex implementation for Library of Congress Genre/Form Terms","ref":"Authoritex.LOC.GenreForms.html"},{"type":"module","title":"Authoritex.LOC.Languages","doc":"Authoritex implementation for Library of Congress MARC List for Languages","ref":"Authoritex.LOC.Languages.html"},{"type":"module","title":"Authoritex.LOC.Names","doc":"Authoritex implementation for Library of Congress Name Authority File","ref":"Authoritex.LOC.Names.html"},{"type":"module","title":"Authoritex.LOC.SubjectHeadings","doc":"Authoritex implementation for Library of Congress Subject Headings","ref":"Authoritex.LOC.SubjectHeadings.html"},{"type":"module","title":"Authoritex.Mock","doc":"Mock Authority for testing Authoritex consumers\n\nExamples:\n  ```\n  # In test.exs:\n  # config :authoritex, authorities: [Authoritex.Mock]\n\n  # In test_helper.exs:\n  # Authoritex.Mock.init()\n\n  # In test case:\n  iex> Authoritex.Mock.set_data([\n    %{id: \"mock:result1\", label: \"First Result\", qualified_label: \"First Result (1)\", hint: \"(1)\"},\n    %{id: \"mock:result2\", label: \"Second Result\", qualified_label: \"Second Result (2)\", hint: \"(2)\"},\n    %{id: \"mock:result3\", label: \"Third Result\", qualified_label: \"Third Result (3)\", hint: \"(3)\"}])\n  :ok\n\n  iex> Authoritex.fetch(\"mock:result2\")\n  {:ok, %{id: \"mock:result2\", label: \"Second Result\", qualified_label: \"Second Result (2)\", hint: \"(2)\"}}\n\n  iex> Authoritex.fetch(\"missing_id_authority:anything\")\n  {:error, 404}\n\n  iex> Authoritex.fetch(\"wrong\")\n  {:error, :unknown_authority}\n\n  iex> Authoritex.search(\"mock\", \"test\")\n  {:ok, [\n          %{id: \"mock:result1\", label: \"First Result\", hint: \"(1)\"},\n          %{id: \"mock:result2\", label: \"Second Result\", hint: \"(2)\"},\n          %{id: \"mock:result3\", label: \"Third Result\", hint: \"(3)\"}\n        ]}\n\n  iex> Authoritex.search(\"mock\", :no_results)\n  {:ok, []}\n\n  iex> Authoritex.search(\"mock\", :error)\n  {:error, 500}\n  ```","ref":"Authoritex.Mock.html"},{"type":"function","title":"Authoritex.Mock.init/0","doc":"","ref":"Authoritex.Mock.html#init/0"},{"type":"function","title":"Authoritex.Mock.set_data/1","doc":"","ref":"Authoritex.Mock.html#set_data/1"},{"type":"module","title":"Authoritex.OpenSearch","doc":"Abstract Authoritex implementation for OpenSearch-backed vocabularies","ref":"Authoritex.OpenSearch.html"},{"type":"module","title":"Authoritex.TestCase","doc":"Shared tests for Authoritex modules\n\n`Authoritex.TestCase` ensures that an authority module implements the\n`Authoritex` behvaiour and that all of its functions behave as expected.\nTo run the shared tests, `use Authoritex.TestCase, opts` within your\ntest module, where `opts` contains:\n\n* `module` -- The module you're testing\n* `code` -- The code returned by the module's `code/0` callback\n* `description` -- The description returned by the module's `description/0` callback\n* `test_uris` -- A list of URIs that should be resolvable by the module, referencing\n  the same resource\n* `bad_uri` -- A URI that is in the correct format but does not point to a resource\n* `expected` -- A keyword list containing the attributes of the resource referenced\n  by the `test_uris`.\n* `search_result_term` -- A term or search query that will include the resource\n  referenced by the `test_uris` in its results\n* `search_count_term` -- A term or search query that will produce at least two\n  pages of results\n* `default_results` (optional) -- The default maximum number of results returned\n  by a search (default: `30`)\n* `specified_results` (optional) -- A non-default number of results that can be\n  used for testing `search/2` (default: `50`)\n```\n\nSee this package's test suite for detailed examples.","ref":"Authoritex.TestCase.html"},{"type":"extras","title":"Introduction","doc":"# Authoritex\n\n[![Build](https://github.com/nulib/authoritex/actions/workflows/build.yml/badge.svg)](https://github.com/nulib/authoritex/actions/workflows/build.yml)\n[![Coverage](https://coveralls.io/repos/github/nulib/authoritex/badge.svg?branch=main)](https://coveralls.io/github/nulib/authoritex?branch=main)\n[![Hex.pm](https://img.shields.io/hexpm/v/authoritex.svg)](https://hex.pm/packages/authoritex)\n\nAn Elixir library for searching and fetching controlled vocabulary authority terms, inspired by\nthe [Samvera Community](https://github.com/samvera)'s [Questioning Authority](https://github.com/samvera/questioning_authority).","ref":"readme.html"},{"type":"extras","title":"Installation - Introduction","doc":"Add `authoritex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:authoritex, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Introduction","doc":"Activate modules for the authorities you want to have available by \nconfiguring them in `config/config.exs`:\n\n```elixir\n# To activate all \nconfig :authoritex,\n  authorities: [\n    Authoritex.FAST.CorporateName,\n    Authoritex.FAST.EventName,\n    Authoritex.FAST.Form,\n    Authoritex.FAST.Geographic,\n    Authoritex.FAST.Personal,\n    Authoritex.FAST.Topical,\n    Authoritex.FAST.UniformTitle,\n    Authoritex.FAST,\n    Authoritex.GeoNames,\n    Authoritex.Getty.AAT,\n    Authoritex.Getty.TGN,\n    Authoritex.Getty.ULAN,\n    Authoritex.Getty,\n    Authoritex.Homosaurus,\n    Authoritex.LOC.GenreForms,\n    Authoritex.LOC.Languages,\n    Authoritex.LOC.Names,\n    Authoritex.LOC.SubjectHeadings,\n    Authoritex.LOC\n  ]\n\n# Authoritex uses httpoison_retry https://github.com/mgwidmann/httpoison_retry\n# Override the config in your application if needed\nconfig :httpoison_retry,\n  max_attempts: 3,\n  wait: 1_000,\n  retry_unknown_errors: false\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Introduction","doc":"See `Authoritex.authorities/0`, `Authoritex.search/2`, `Authoritex.search/3`, \nand `Authoritex.fetch/1`.","ref":"readme.html#usage"},{"type":"extras","title":"Implementing Additional Authorities - Introduction","doc":"* Create a module implementing the `Authoritex` behaviour\n* Create a test module using the `Authoritex.TestCase` module\n* `Authoritex` uses `ExVCR` to cache HTTP requests in the\n  test suite. If you're seeing unexpected results during development,\n  run `mix vcr.delete CODE_` (where `CODE` is your authority module's\n  unique short code) to clear that authority's cached results","ref":"readme.html#implementing-additional-authorities"},{"type":"extras","title":"Testing using mocks - Introduction","doc":"See `Authoritex.Mock`","ref":"readme.html#testing-using-mocks"},{"type":"extras","title":"Supported Elixir/OTP versions - Introduction","doc":"`Authoritex` supports (i.e., is tested against) a matrix consisting of the three most recent Elixir minor versions and up to three most recent Erlang/OTP major versions (depending on Elixir compatibility). Right now, that means:\n\n| Elixir/OTP | 24 | 23 | 22 |\n|------------|----|----|----|\n| **1.12**   | ✔️  | ✔️  | ✔️  |\n| **1.11**   | ✔️  | ✔️  | ✔️  |\n| **1.10**   |    | ✔️  | ✔️  |\n\nSupport for other versions/combinations is possible (probable, even), but unsupported.","ref":"readme.html#supported-elixir-otp-versions"},{"type":"extras","title":"Contributing - Introduction","doc":"Issues and Pull Requests are always welcome!","ref":"readme.html#contributing"},{"type":"extras","title":"Livebook Notebook","doc":"# Getting Started With Authoritex","ref":"livebook.html"},{"type":"extras","title":"About - Livebook Notebook","doc":"An Elixir library for searching and fetching controlled vocabulary authority terms, inspired by the [Samvera Community's](https://github.com/samvera) [Questioning Authority](https://github.com/samvera/questioning_authority).\n\n`Authoritex` provides an [Elixir behaviour](https://elixir-lang.org/getting-started/typespecs-and-behaviours.html#behaviours) that defines a specification for creating authorities. Each authority is a module which has to implement at least 5 public functions: `can_resolve?/1`, `code/0`, `description/0`, `fetch/1`, and `search/2`.\n\n* `can_resolve?/1` Returns true if the module can resolve the given identifier\n* `code/0` Returns the unique short code for the authority\n* `description/0` Returns a human-readable description of the authority\n* `fetch/1` Fetches a label (and optional hint string) for a specified resource\n* `search/2` Returns a list of search results (and optional hints) matching a query","ref":"livebook.html#about"},{"type":"extras","title":"Installation - Livebook Notebook","doc":"```elixir\nMix.install([\n  {:authoritex, \"~> 0.7.0\"},\n  {:kino, \"~> 0.5.2\"}\n])\n```","ref":"livebook.html#installation"},{"type":"extras","title":"Configuration - Livebook Notebook","doc":"```elixir\nApplication.put_env(:authoritex, :authorities, [\n  Authoritex.FAST.CorporateName,\n  Authoritex.FAST.EventName,\n  Authoritex.FAST.Form,\n  Authoritex.FAST.Geographic,\n  Authoritex.FAST.Personal,\n  Authoritex.FAST.Topical,\n  Authoritex.FAST.UniformTitle,\n  Authoritex.FAST,\n  Authoritex.GeoNames,\n  Authoritex.Getty.AAT,\n  Authoritex.Getty.TGN,\n  Authoritex.Getty.ULAN,\n  Authoritex.Getty,\n  Authoritex.LOC.Languages,\n  Authoritex.LOC.Names,\n  Authoritex.LOC.SubjectHeadings\n])\n```","ref":"livebook.html#configuration"},{"type":"extras","title":"List configured authorities - Livebook Notebook","doc":"`Authoritex.authorities/0` returns a list of tuples describing all configured authorities.\n\n```elixir\nAuthoritex.authorities()\n```","ref":"livebook.html#list-configured-authorities"},{"type":"extras","title":"Fetch records by id - Livebook Notebook","doc":"`Authoritex.fetch/1` returns a map with the `:label`, `:id`, `:hint`, and `:qualified_label` for an authority record given an id (must be a string).\n\n```elixir\n# Known authority and record identifier\nAuthoritex.fetch(\"http://id.loc.gov/authorities/names/no2011087251\")\n```\n\n`Authoritex.fetch/1` returns the error tuple `{:error, 404}` given an unknown id for a properly configured authority.\n\n```elixir\n# Known authority with unknown record identifier\nAuthoritex.fetch(\"http://id.loc.gov/authorities/names/unknown-id\")\n```\n\n`Authoritex.fetch/1` returns the error tuple `{:error, :unknown_authority}` given an id for an unknown authority.\n\n```elixir\n# Unknown authority\nAuthoritex.fetch(\"http://fake.authority.org/not-a-real-thing\")\n```","ref":"livebook.html#fetch-records-by-id"},{"type":"extras","title":"Search an authority - Livebook Notebook","doc":"`Authoritex.search/2` performs a search with an authority and a search term. The following select menu lets you choose a supported authority:\n\n```elixir\nsearch_authority =\n  Kino.Input.select(\n    \"Select Authority\",\n    [\n      {\"aat\", \"Getty Art & Architecture Thesaurus (AAT)\"},\n      {\"fast\", \"Faceted Application of Subject Terminology (FAST)  -- Base\"},\n      {\"fast-corporate-name\", \"Faceted Application of Subject Terminology -- Corporate Name\"},\n      {\"fast-event-name\", \"Faceted Application of Subject Terminology -- Event Name\"},\n      {\"fast-form\", \"Faceted Application of Subject Terminology -- Form/Genre\"},\n      {\"fast-geographic\", \"Faceted Application of Subject Terminology -- Geographic\"},\n      {\"fast-personal\", \"Faceted Application of Subject Terminology -- Personal\"},\n      {\"fast-topical\", \"Faceted Application of Subject Terminology -- Topical\"},\n      {\"fast-uniform-title\", \"Faceted Application of Subject Terminology -- Uniform Title\"},\n      {\"getty\", \"Getty -- Base\"},\n      {\"lclang\", \"Library of Congress MARC List for Languages\"},\n      {\"lcnaf\", \"Library of Congress Name Authority File\"},\n      {\"lcsh\", \"Library of Congress Subject Headings\"},\n      {\"tgn\", \"Getty Thesaurus of Geographic Names (TGN)\"},\n      {\"ulan\", \"Getty Union List of Artist Names (ULAN)\"}\n    ]\n  )\n\n```\n\nEnter a search term in the text input:\n\n```elixir\nsearch_term = Kino.Input.text(\"Search term\")\n```\n\nPerform the search using the values chosen above:\n\n<!-- livebook:{\"reevaluate_automatically\":true} -->\n\n```elixir\nAuthoritex.search(Kino.Input.read(search_authority), Kino.Input.read(search_term))\n```\n\n`Authoritex.search/3` takes the same arguments as `Authoritex.search/2` along with a third argument (must be an integer) to limit the result count of the search.\n\n```elixir\nAuthoritex.search(\"lcsh\", \"library\", 3)\n```\n\n```elixir\n# Error recevied when searching an unknown authority\nAuthoritex.search(\"not-an-authority\", \"test\")\n```","ref":"livebook.html#search-an-authority"},{"type":"extras","title":"Testing - Livebook Notebook","doc":"`Authoritex` provides a mock for testing purposes in consuming applications.\n\nConfigure the mock with a few lines of code:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n# In test.exs:\nconfig :authoritex, authorities: [Authoritex.Mock]\n\n# In test_helper.exs:\nAuthoritex.Mock.init()\n```\n\nUse the `Authoritex.Mock.set_data/1` function to add data for testing purposes, typically in a `setup` block. The example module below demonstrates an `ExUnit` test using the `Authoritex.Mock`. The `Authoritex.Mock.search/1` function returns all mock data regardless of the string passed to the function. (Note: the following code is a code sample that is not runnable like the examples above):\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\ndefmodule MyTest do\n  alias Authoritex.Mock\n  use ExUnit.Case, async: true\n\n  @data [\n      %{\n        id: \"mock:result1\",\n        label: \"First Result\",\n        qualified_label: \"First Result (1)\",\n        hint: \"(1)\"\n      },\n      %{\n        id: \"mock:result2\",\n        label: \"Second Result\",\n        qualified_label: \"Second Result (2)\",\n        hint: \"(2)\"\n      },\n      %{id: \"mock:result3\", label: \"Third Result\", qualified_label: \"Third Result (3)\", hint: \"(3)\"}\n    ]\n\n  setup do\n    Mock.set_data(@data)\n    :ok\n  end\n\n  test \"results\" do\n    with {:ok, results} <- Mock.search(\"any\") do\n      assert length(results) == length(@data)\n    end\n  end\nend\n```","ref":"livebook.html#testing"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2020 Northwestern University Libraries\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}